pub struct DynamicArray<T, TAllocator>where
TAllocator: Allocator,{ /* private fields */ }Expand description
A #[repr(C)] variant of the standard vec struct.
Functionally similar, and implements [ReprC] for T: ReprC. However,
unlike vec this struct multiplies capacity by 3/2 when resizing is
needed.
Implementations
Sourceimpl<T, TAllocator> DynamicArray<T, TAllocator>where
TAllocator: Allocator,
impl<T, TAllocator> DynamicArray<T, TAllocator>where
TAllocator: Allocator,
Sourcepub fn new() -> Selfwhere
TAllocator: Default,
pub fn new() -> Selfwhere
TAllocator: Default,
Creates a new, empty DynamicArray.
Sourcepub const fn with_allocator(allocator: TAllocator) -> Self
pub const fn with_allocator(allocator: TAllocator) -> Self
Creates a new, empty DynamicArray with an allocator.
Sourcepub fn with_capacity_and_allocator(
capacity: Length,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub fn with_capacity_and_allocator( capacity: Length, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new DynamicArray with capacity and allocator.
This allocates memory only when capacity > 0.
Errors
For details see ArrayError.
Sourcepub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
pub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
Creates a new DynamicArray with capacity and the default allocator.
This allocates memory only when capacity > 0.
Errors
For details see ArrayError.
Sourcepub fn with_factory<Factory: FnMut(usize) -> T>(
size: Length,
factory: Factory,
) -> Result<Self, ArrayError>where
TAllocator: Default,
pub fn with_factory<Factory: FnMut(usize) -> T>(
size: Length,
factory: Factory,
) -> Result<Self, ArrayError>where
TAllocator: Default,
Creates a new DynamicArray with a given size, generated through a given factory.
This allocates memory only when size > 0.
Notes
This method is functionally equivalent to initializing an empty vector and running
factory one by one in a loop, and passing it to
push. This way, however, is more efficient,
even if you preallocate the vector with capacity. Because this method gives the
compiler an opportunity to vectorize the construction, unlike sequential
push calls.
Errors
For details see ArrayError.
Sourcepub fn with_factory_and_allocator<Factory: FnMut(usize) -> T>(
size: Length,
factory: Factory,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub fn with_factory_and_allocator<Factory: FnMut(usize) -> T>( size: Length, factory: Factory, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new DynamicArray with a given size, generated through a given factory,
with a custom allocator. This allocates memory only when size > 0.
Notes
This method is functionally equivalent to initializing an empty vector and running
factory one by one in a loop, and passing it to
push. This way, however, is more efficient,
even if you preallocate the vector with capacity. Because this method gives the
compiler an opportunity to vectorize the construction, unlike sequential
push calls.
Errors
For details see ArrayError.
Sourcepub unsafe fn with_size_uninitialized(size: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
pub unsafe fn with_size_uninitialized(size: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
Creates a new DynamicArray with a given size, but uninitialized.
Safety
The underlying array is uninitialized and reading the data is UB, unless initialized first.
Errors
For details see ArrayError.
Sourcepub unsafe fn with_size_and_allocator_uninitialized(
size: Length,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub unsafe fn with_size_and_allocator_uninitialized( size: Length, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new DynamicArray with a given size and allocator, but uninitialized.
Safety
The underlying array is uninitialized and reading the data is UB, unless initialized first.
Errors
For details see ArrayError.