pub struct InlineDynamicArray<const TCAPACITY: usize, T, TAllocator>where
T: Sized,
TAllocator: Allocator,{ /* private fields */ }Expand description
Represents a dynamic array, where first TCAPACITY items are inlined in the struct itself.
In other words, this array allocates memory only when its length exceeds TCAPACITY. In which
case it allocates data on heap, and becomes a slightly less efficient variant of
DynamicArray.
Similarly to DynamicArray this struct resizes the
underlying buffer by multiplying capacity by 3/2.
Implementations
Sourceimpl<const TCAPACITY: usize, T, TAllocator> InlineDynamicArray<TCAPACITY, T, TAllocator>where
T: Sized,
TAllocator: Allocator,
impl<const TCAPACITY: usize, T, TAllocator> InlineDynamicArray<TCAPACITY, T, TAllocator>where
T: Sized,
TAllocator: Allocator,
Sourcepub fn new() -> Selfwhere
TAllocator: Default,
pub fn new() -> Selfwhere
TAllocator: Default,
Creates a new empty InlineDynamicArray with the default TAllocator.
Sourcepub const fn with_allocator(allocator: TAllocator) -> Self
pub const fn with_allocator(allocator: TAllocator) -> Self
Creates a new empty InlineDynamicArray with the given TAllocator.
Sourcepub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
pub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
Creates a new InlineDynamicArray with the default TAllocator. This method allocates memory
if capacity exceeds TCAPACITY.
Errors
For details see ArrayError.
Sourcepub fn with_capacity_and_allocator(
capacity: Length,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub fn with_capacity_and_allocator( capacity: Length, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new InlineDynamicArray with the given TAllocator. This method allocates memory
if capacity exceeds TCAPACITY.
Errors
For details see ArrayError.